api.reputation.v1.override.test_helpers.override_domain package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.override.test_helpers.override_domain package

## Submodules

## api.reputation.v1.override.test_helpers.override_domain.add_address_overrides module

`api.reputation.v1.override.test_helpers.override_domain.add_address_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.add_address_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.add_address_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.add_address_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.add_domain_override module

`api.reputation.v1.override.test_helpers.override_domain.add_domain_override.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.add_domain_override.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.add_domain_override.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.add_domain_override.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.add_override_list module

`api.reputation.v1.override.test_helpers.override_domain.add_override_list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.add_override_list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.add_override_list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.add_override_list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.delete_address_override module

`api.reputation.v1.override.test_helpers.override_domain.delete_address_override.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.delete_address_override.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.delete_address_override.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.delete_address_override.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.delete_address_overrides module

`api.reputation.v1.override.test_helpers.override_domain.delete_address_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.delete_address_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.delete_address_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.delete_address_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.delete_domain_override module

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_override.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_override.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_override.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_override.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.delete_domain_overrides module

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.delete_domain_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.delete_override_list module

`api.reputation.v1.override.test_helpers.override_domain.delete_override_list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.delete_override_list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.delete_override_list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.delete_override_list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.find_address_overrides module

`api.reputation.v1.override.test_helpers.override_domain.find_address_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/search, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.find_address_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/search, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.find_address_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/search, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.find_address_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/search, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.find_domain_overrides module

`api.reputation.v1.override.test_helpers.override_domain.find_domain_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/search, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.find_domain_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/search, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.find_domain_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/search, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.find_domain_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/search, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_override_for_domain module

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_domain.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_domain.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_domain.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_domain.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_override_for_i_p module

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_i_p.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_i_p.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_i_p.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_override_for_i_p.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_override_list_by_id module

`api.reputation.v1.override.test_helpers.override_domain.get_override_list_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_override_list_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_override_list_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_override_list_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_override_lists module

`api.reputation.v1.override.test_helpers.override_domain.get_override_lists.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_override_lists.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_override_lists.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_override_lists.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_domain module

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_domain.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_domain.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_domain.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_domain.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_i_p module

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_i_p.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_i_p.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_i_p.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.get_overrides_for_i_p.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip/w+, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.list_address_overrides module

`api.reputation.v1.override.test_helpers.override_domain.list_address_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.list_address_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.list_address_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.list_address_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/ip, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.list_domain_overrides module

`api.reputation.v1.override.test_helpers.override_domain.list_domain_overrides.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.list_domain_overrides.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.list_domain_overrides.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.list_domain_overrides.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/domain, respond with HTTP 401

## api.reputation.v1.override.test_helpers.override_domain.update_override_list module

`api.reputation.v1.override.test_helpers.override_domain.update_override_list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 403

`api.reputation.v1.override.test_helpers.override_domain.update_override_list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 404

`api.reputation.v1.override.test_helpers.override_domain.update_override_list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 200

`api.reputation.v1.override.test_helpers.override_domain.update_override_list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/override/list/w+, respond with HTTP 401

## Module contents